<div align="center">

</div>

<div align="center">

![Neuralk SDK](https://neuralk-ai.github.io/neuralk/_images/cover.png)

</div>

<h3 align="center">A Tabular Machine Learning SDK for Industrial Applications</h3>

<p align="center">
  <a href="https://docs.neuralk-ai.com/"><strong>[API reference]</strong></a>
</p>

## 👋 Welcome to the Neuralk SDK

The Neuralk SDK provides a simple and powerful Python interface to our services.
It lets you access our foundation models directly or through advanced, domain-specific workflows.
To learn about it please refer to the [documentation](https://docs.neuralk-ai.com/).

## Citing Neuralk

If you incorporate any part of this repository into your work, please reference it using the following citation:

```bibtex
@article{neuralk2025sdk,
         title={Neuralk: A Foundation Model for Industrial Tabular Data},
         author={Neuralk-AI},
         year={2025},
         publisher = {GitHub},
         howpublished = {\url{https://www.neuralk-ai.com/}},
}
```

# Contact

If you have any questions or wish to propose new features please feel free to open an issue or contact us at alex@neuralk-ai.com.

For collaborations please contact us at antoine@neuralk-ai.com.
